#if !defined(__UUIDGEN_H)
    #define __UUIDGEN_H
/******************************************************************************/
/*                                                                            */
/* Licensed Materials - Property of IBM                                       */
/* (C) Copyright IBM Corp. 2000                                               */
/*                                                                            */
/* Program name    : uuidgen.h                                                */
/*                                                                            */
/* Description     : This header file contains function prototypes and        */
/*                   constants for the uuidgen plugin source files            */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Version 1.0                                                                */
/* Author: Mike Brady                      Date: July 2001                    */
/*                                                                            */
/******************************************************************************/

#if defined(WIN32)
	#include <windows.h>
	#include <winbase.h>
#endif

#include <wchar.h>
#include <BipCci.h>	  /* Data types for Plug-in Node functions     */

#include <trace_publ.h>
#include "plugin.h"

#if defined(__THREADED)
    #include "threads.h"
#endif

#include <cmqc.h>
#include "unicode.h"
#include "utilities.h"
#include "MQSIV2_uuidgen_msg.h"
#include "rc.h"
#include "uuidgen_constants.h"
#include "uuid.h"

#if defined(_AIX) || defined(_SOLARIS)
    #include <values.h>
    #define INFINITE MAXINT
#endif

/* constants */
#if !defined(IN)
    #define IN
#endif
#if !defined(OUT)
    #define OUT
#endif
#if !defined(INOUT)
    #define INOUT
#endif
#if !defined(TRUE)
    #define TRUE 1
#endif
#if !defined(FALSE)
    #define FALSE 0
#endif
#if !defined(bool_t)
    #define bool_t int
#endif

#define UUIDGEN_DATA_BEGIN_TAG "<TimerEventData>"
#define UUIDGEN_DATA_END_TAG "</TimerEventData>"
#define UUIDGEN_DATA_NULL_TAG "<TimerEventData/>"


/* return sequence numbers */
#define RSN_001     1
#define RSN_002     2
#define RSN_003     3
#define RSN_004     4
#define RSN_005     5
#define RSN_006     6
#define RSN_007     7
#define RSN_008     8
#define RSN_009     9
#define RSN_010     10
#define RSN_011     11
#define RSN_012     12
#define RSN_013     13
#define RSN_014     14
#define RSN_015     15
#define RSN_016     16
#define RSN_017     17
#define RSN_018     18
#define RSN_019     19
#define RSN_020     20
#define RSN_021     21
#define RSN_022     22
#define RSN_023     23
#define RSN_024     24
#define RSN_025     25
#define RSN_026     26
#define RSN_027     27
#define RSN_028     28
#define RSN_029     29
#define RSN_030     30
#define RSN_031     31
#define RSN_032     32
#define RSN_033     33
#define RSN_034     34
#define RSN_035     35
#define RSN_036     36
#define RSN_037     37
#define RSN_038     38
#define RSN_039     39
#define RSN_040     40
#define RSN_041     41
#define RSN_042     42
#define RSN_043     43
#define RSN_044     44
#define RSN_045     45
#define RSN_046     46
#define RSN_047     47
#define RSN_048     48
#define RSN_049     49
#define RSN_050     50

typedef struct deployedUuidgen {
	CciChar *copyValueToLocation;
	bool_t includeSeparators;
	struct deployedUuidgen *nextP,
		                   *prevP;
} deployedUuidgen_t;
#define DEPLOYED_UUIDGEN_DEFAULT \
	                   NULL,  /* copyValueToLocation */  \
					   FALSE, /* includeSeparators */ \
	                   NULL,  /* nextP */ \
					   NULL   /* prevP */

typedef enum
{
	UUID_CREATE = 1
} nodeType_t;


extern char *traceRetcodeStrings[];
extern int traceMaxRetcodeValue;

#if defined(GLOBAL_UUIDGEN_DATA)
	/* global variables */
    threadMutex_t uuidGenMutex;
	bool_t brokerInfoObtained = FALSE,
		   firstTraceCall = TRUE;

	messageFlow_t messageFlowAnchor = {MESSAGE_FLOW_DEFAULT};

	deployedUuidgen_t uuidgenAnchor = {DEPLOYED_UUIDGEN_DEFAULT},
		           *uuidgenAnchorP = &uuidgenAnchor;

	char queueManagerName[MQ_Q_MGR_NAME_LENGTH+1] = "";
	char brokerName[MAX_STRING_SIZE+1] = "";
	char executionGroupName[MAX_STRING_SIZE+1] = "";
	char messageFlowName[MAX_STRING_SIZE+1] = "";

	CciChar queueManagerNameUC[MQ_Q_MGR_NAME_LENGTH+1];
	CciChar brokerNameUC[MAX_STRING_SIZE+1];
	CciChar executionGroupNameUC[MAX_STRING_SIZE+1];
	CciChar messageFlowNameUC[MAX_STRING_SIZE+1];
	
	int currentPID = 0,
		numUuidCreateNodes = 0;

	/* trace stuff */
	char *callersTraceEnvironmentVariable = "UUIDGEN_PLUGIN_TRACE";
	int traceCallerIndex;
#else
	/* global variables */
    extern threadMutex_t uuidGenMutex;
	extern bool_t brokerInfoObtained,
		          firstTraceCall;

	extern messageFlow_t messageFlowAnchor;

	extern deployedUuidgen_t uuidgenAnchor,
		                     *uuidgenAnchorP;
	extern char queueManagerName[];
	extern char brokerName[];
	extern char executionGroupName[];
	extern char messageFlowName[];

	extern CciChar queueManagerNameUC[];
	extern CciChar brokerNameUC[];
	extern CciChar executionGroupNameUC[];
	extern CciChar messageFlowNameUC[];
	
	extern int currentPID,
		       numUuidCreateNodes;

	/* trace stuff */
	extern char *callersTraceEnvironmentVariable;
	extern int traceCallerIndex;
#endif


/* Function Prototypes */
int evaluateUuidCreate(context_t *contextP,
		               CciMessage *destinationList,
		               CciMessage *exceptionList,
		               CciMessage *message);

void *getMessageIdElement(IN void *message);

int propagateMessage(IN context_t *contextP,
					 IN CciChar *terminalName,
					 IN void *message,
					 IN void *destinationList,
					 IN void *exceptionList,
                     IN bool_t newMessage);	

int processAttribute(IN context_t *contextP,
				     IN CciChar *attributeName,
				     IN CciChar *attributeValue);

int applyDataToElement(IN CciElement *elementP, 
					   IN uuid_t *uuidP);



#define RETHROW_IF_EXCEPTION(__rc) \
if (__rc == TT_PROPAGATION_EXCEPTION) \
		{ \
	/* about to re-throw last exception, reset the trace indentation first */ \
	TRACE_MID(TRACE_INFO, ("About to rethrow exception, resetting trace indentation")); \
	TraceSetIndentationValue(0); \
	cciRethrowLastException(0); \
}


#endif

