#if !defined(__UUIDGEN_CONSTANTS_H)
    #define __UUIDGEN_CONSTANTS_H
/******************************************************************************/
/*                                                                            */
/* Licensed Materials - Property of IBM                                       */
/* (C) Copyright IBM Corp. 2000                                               */
/*                                                                            */
/* Program name    : uuidgen_constants.h                                      */
/*                                                                            */
/* Description     : This header file contains unicode constants for the      */
/*                   uuidgen plug-in node.                                    */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Version 1.0                                                                */
/* Author: Mike Brady                      Date: Jul 2001                     */
/*                                                                            */
/******************************************************************************/

#include <BipCci.h>	  /* Data types for Plug-in Node functions     */

#if defined(WIN32)  // little endian, so no need to shift bytes 
	#define UC(__char) ((CciChar)__char)
	#define UCB ((CciChar)' ')
	#define UCDOT ((CciChar)'.')
#elif defined(_SOLARIS) || defined(_HPUX)
	#define UC(__char) (((CciChar)__char))
	#define UCB (((CciChar)' '))
	#define UCDOT (((CciChar)'.'))
#else
	#define UC(__char) (((CciChar)__char)<<8)
	#define UCB (((CciChar)' ')<<8)
	#define UCDOT (((CciChar)'.')<<8)
#endif

typedef struct uuidgenConstants {
    CciChar 
        *PLUGIN_MESSAGE_CATALOGUE,
        *UUID_CREATE_NODE,
        *ATTR_COPY_VALUE_TO,
        *ATTR_INCLUDE_SEPARATORS,
        *ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE,
        *ATTR_LABEL,
        *ATTR_USER_TRACE_LEVEL,
        *ATTR_TRACE_LEVEL,
        *ATTR_USER_TRACE_FILTER,
        *ATTR_TRACE_FILTER,
        *TERM_IN,
        *TERM_OUT,
        *TERM_FAILURE,
        *ROOT_DOT,
        *ROOT_DOT_MQMD_DOT,
        *ROOT_DOT_PROPERTIES_DOT,
        *ROOT_DOT_XML,
        *ROOT_DOT_XML_DOT,
        *NULL_LITERAL,
        *UUIDGEN_PLUGIN_FACTORY,
        DOT_CHAR;
} uuidgenConstants_t;

/* build static initialisation values for Solaris */
#if defined(_SOLARIS) || defined(_HPUX)

#if defined(GLOBAL_UUIDGEN_DATA)
CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[sizeof("MQSIV2_uuidgen")*sizeof(CciChar)] =
    {'M','Q','S','I','V','2','_','u','u','i','d','g','e','n',0},
    UUID_CREATE_NODE_VAL[sizeof("UuidCreateNode")*sizeof(CciChar)] =
    {'U','u','i','d','C','r','e','a','t','e','N','o','d','e',0},
    ATTR_COPY_VALUE_TO_VAL[sizeof("CopyValueTo")*sizeof(CciChar)] =
    {'C','o','p','y','V','a','l','u','e','T','o',0},
    ATTR_INCLUDE_SEPARATORS_VAL[sizeof("IncludeSeparators")*sizeof(CciChar)] =
    {'I','n','c','l','u','d','e','S','e','p','a','r','a','t','o','r','s',0},
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL[sizeof("false")*sizeof(CciChar)] =
    {'f','a','l','s','e',0},
    ATTR_LABEL_VAL[sizeof("label")*sizeof(CciChar)] =
    {'l','a','b','e','l',0},
    ATTR_USER_TRACE_LEVEL_VAL[sizeof("userTraceLevel")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','L','e','v','e','l',0},
    ATTR_TRACE_LEVEL_VAL[sizeof("traceLevel")*sizeof(CciChar)] =
    {'t','r','a','c','e','L','e','v','e','l',0},
    ATTR_USER_TRACE_FILTER_VAL[sizeof("userTraceFilter")*sizeof(CciChar)] =
    {'u','s','e','r','T','r','a','c','e','F','i','l','t','e','r',0},
    ATTR_TRACE_FILTER_VAL[sizeof("traceFilter")*sizeof(CciChar)] =
    {'t','r','a','c','e','F','i','l','t','e','r',0},
    TERM_IN_VAL[sizeof("in")*sizeof(CciChar)] =
    {'i','n',0},
    TERM_OUT_VAL[sizeof("out")*sizeof(CciChar)] =
    {'o','u','t',0},
    TERM_FAILURE_VAL[sizeof("failure")*sizeof(CciChar)] =
    {'f','a','i','l','u','r','e',0},
    ROOT_DOT_VAL[sizeof("Root.")*sizeof(CciChar)] =
    {'R','o','o','t','.',0},
    ROOT_DOT_MQMD_DOT_VAL[sizeof("Root.MQMD.")*sizeof(CciChar)] =
    {'R','o','o','t','.','M','Q','M','D','.',0},
    ROOT_DOT_PROPERTIES_DOT_VAL[sizeof("Root.Properties.")*sizeof(CciChar)] =
    {'R','o','o','t','.','P','r','o','p','e','r','t','i','e','s','.',0},
    ROOT_DOT_XML_VAL[sizeof("Root.XML")*sizeof(CciChar)] =
    {'R','o','o','t','.','X','M','L',0},
    ROOT_DOT_XML_DOT_VAL[sizeof("Root.XML.")*sizeof(CciChar)] =
    {'R','o','o','t','.','X','M','L','.',0},
    NULL_LITERAL_VAL[sizeof("null")*sizeof(CciChar)] =
    {'n','u','l','l',0},
    UUIDGEN_PLUGIN_FACTORY_VAL[sizeof("UuidgenPlugInFactory")*sizeof(CciChar)] =
    {'U','u','i','d','g','e','n','P','l','u','g','I','n','F','a','c','t','o','r','y',0};
#else
extern CciChar 
    PLUGIN_MESSAGE_CATALOGUE_VAL[],
    UUID_CREATE_NODE_VAL[],
    ATTR_COPY_VALUE_TO_VAL[],
    ATTR_INCLUDE_SEPARATORS_VAL[],
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL[],
    ATTR_LABEL_VAL[],
    ATTR_USER_TRACE_LEVEL_VAL[],
    ATTR_TRACE_LEVEL_VAL[],
    ATTR_USER_TRACE_FILTER_VAL[],
    ATTR_TRACE_FILTER_VAL[],
    TERM_IN_VAL[],
    TERM_OUT_VAL[],
    TERM_FAILURE_VAL[],
    ROOT_DOT_VAL[],
    ROOT_DOT_MQMD_DOT_VAL[],
    ROOT_DOT_PROPERTIES_DOT_VAL[],
    ROOT_DOT_XML_VAL[],
    ROOT_DOT_XML_DOT_VAL[],
    NULL_LITERAL_VAL[],
    UUIDGEN_PLUGIN_FACTORY_VAL[];
#endif
#endif


/* define the initialisation macro */
#if defined(WIN32) || defined(_AIX)
#define UUIDGEN_CONSTANTS_DEFAULTS \
    L"MQSIV2_uuidgen", \
    L"UuidCreateNode", \
    L"CopyValueTo", \
    L"IncludeSeparators", \
    L"false", \
    L"label", \
    L"userTraceLevel", \
    L"traceLevel", \
    L"userTraceFilter", \
    L"traceFilter", \
    L"in", \
    L"out", \
    L"failure", \
    L"Root.", \
    L"Root.MQMD.", \
    L"Root.Properties.", \
    L"Root.XML", \
    L"Root.XML.", \
    L"null", \
    L"UuidgenPlugInFactory", \
    L'.'


#elif defined(_SOLARIS) || defined(_HPUX)

#define UUIDGEN_CONSTANTS_DEFAULTS \
    PLUGIN_MESSAGE_CATALOGUE_VAL, \
    UUID_CREATE_NODE_VAL, \
    ATTR_COPY_VALUE_TO_VAL, \
    ATTR_INCLUDE_SEPARATORS_VAL, \
    ATTR_INCLUDE_SEPARATORS_DEFAULT_VALUE_VAL, \
    ATTR_LABEL_VAL, \
    ATTR_USER_TRACE_LEVEL_VAL, \
    ATTR_TRACE_LEVEL_VAL, \
    ATTR_USER_TRACE_FILTER_VAL, \
    ATTR_TRACE_FILTER_VAL, \
    TERM_IN_VAL, \
    TERM_OUT_VAL, \
    TERM_FAILURE_VAL, \
    ROOT_DOT_VAL, \
    ROOT_DOT_MQMD_DOT_VAL, \
    ROOT_DOT_PROPERTIES_DOT_VAL, \
    ROOT_DOT_XML_VAL, \
    ROOT_DOT_XML_DOT_VAL, \
    NULL_LITERAL_VAL, \
    UUIDGEN_PLUGIN_FACTORY_VAL, \
    '.'
#endif


/* finally, define the global initializer structure */
#if defined(GLOBAL_UUIDGEN_DATA)
    uuidgenConstants_t C = {UUIDGEN_CONSTANTS_DEFAULTS};
#else
    extern uuidgenConstants_t C;
#endif


#define UUID_CREATE_NODE_MB "UuidCreateNode"
#define ATTR_COPY_VALUE_TO_MB "CopyValueTo"


#define NULL_24 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48 \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
#define NULL_48_AND_TRAILING_NULL \
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

#endif
